namespace efl { namespace pack { 
inline ::efl::eolian::return_traits<bool>::type Linear::pack_begin( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj) const
{
   Eina_Bool __return_value =  ::efl_pack_begin(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Linear::pack_end( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj) const
{
   Eina_Bool __return_value =  ::efl_pack_end(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Linear::pack_before( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj,  ::efl::eolian::in_traits< ::efl::Gfx>::type existing) const
{
   Eina_Bool __return_value =  ::efl_pack_before(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj)
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx const*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(existing));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Linear::pack_after( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj,  ::efl::eolian::in_traits< ::efl::Gfx>::type existing) const
{
   Eina_Bool __return_value =  ::efl_pack_after(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj)
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx const*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(existing));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Linear::pack_at( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj,  ::efl::eolian::in_traits<int>::type index) const
{
   Eina_Bool __return_value =  ::efl_pack_at(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Linear::pack_content_get( ::efl::eolian::in_traits<int>::type index) const
{
    ::Efl_Gfx* __return_value =  ::efl_pack_content_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Linear::pack_index_get( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj) const
{
   int __return_value =  ::efl_pack_index_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx const*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(subobj));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Linear::pack_unpack_at( ::efl::eolian::in_traits<int>::type index) const
{
    ::Efl_Gfx* __return_value =  ::efl_pack_unpack_at(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace efl { namespace pack { 
inline ::efl::eolian::return_traits<bool>::type Linear::pack_begin( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj) const
{
   Eina_Bool __return_value =  ::efl_pack_begin(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Linear::pack_end( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj) const
{
   Eina_Bool __return_value =  ::efl_pack_end(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Linear::pack_before( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj,  ::efl::eolian::in_traits< ::efl::Gfx>::type existing) const
{
   Eina_Bool __return_value =  ::efl_pack_before(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj)
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx const*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(existing));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Linear::pack_after( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj,  ::efl::eolian::in_traits< ::efl::Gfx>::type existing) const
{
   Eina_Bool __return_value =  ::efl_pack_after(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj)
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx const*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(existing));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Linear::pack_at( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj,  ::efl::eolian::in_traits<int>::type index) const
{
   Eina_Bool __return_value =  ::efl_pack_at(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type, true>(subobj)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Linear::pack_content_get( ::efl::eolian::in_traits<int>::type index) const
{
    ::Efl_Gfx* __return_value =  ::efl_pack_content_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Linear::pack_index_get( ::efl::eolian::in_traits< ::efl::Gfx>::type subobj) const
{
   int __return_value =  ::efl_pack_index_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx const*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(subobj));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Linear::pack_unpack_at( ::efl::eolian::in_traits<int>::type index) const
{
    ::Efl_Gfx* __return_value =  ::efl_pack_unpack_at(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline efl::pack::Linear::operator ::efl::pack::Linear() const { return *static_cast< ::efl::pack::Linear const*>(static_cast<void const*>(this)); }
inline efl::pack::Linear::operator ::efl::pack::Linear&() { return *static_cast< ::efl::pack::Linear*>(static_cast<void*>(this)); }
inline efl::pack::Linear::operator ::efl::pack::Linear const&() const { return *static_cast< ::efl::pack::Linear const*>(static_cast<void const*>(this)); }
} } }

